OC.L10N.register(
    "user_migrate",
    {
    "Export" : "Exportar",
    "Something went wrong while the export file was being generated" : "Il occurreva alcun cosa erronee durante le generation del file de exportation",
    "An error has occurred" : "Il occurreva un error",
    "Account Export/Import" : "Importation/exportation de conto",
    "Import" : "Importar"
},
"nplurals=2; plural=(n != 1);");
